@@ -29,15 +29,15 @@ module Slim
           tmp = unique_name
           [:multi,
            [:code, "#{tmp} = #{code}"],
-           [:case, tmp,
-            ['true', [:html, :attr, name, [:multi]]],
-            ['false, nil', [:multi]],
-            [:else, [:html, :attr, name, [:escape, escape, [:dynamic, tmp]]]]]]
+           [:if, tmp,
+            [:if, "#{tmp} == true",
+             [:html, :attr, name, [:multi]],
+             [:html, :attr, name, [:escape, escape, [:dynamic, tmp]]]]]]
         end
       else
         # Attribute with merging
         @attr = name
-        return super
+        super
       end
     end
 
@@ -54,7 +54,7 @@ module Slim
          [:code, "#{tmp} = #{code}"],
          [:if, "Array === #{tmp}",
           [:multi,
-           [:code, "#{tmp}.flatten!"],
+           [:code, "#{tmp} = #{tmp}.flatten"],
            [:code, "#{tmp}.map!(&:to_s)"],
            [:code, "#{tmp}.reject!(&:empty?)"],
            [:escape, escape, [:dynamic, "#{tmp}.join(#{delimiter.inspect})"]]],
